@@ -2,7 +2,7 @@
 sudo.views
 ~~~~~~~~~~
 
-:copyright: (c) 2014 by Matt Robenolt.
+:copyright: (c) 2020 by Matt Robenolt.
 :license: BSD, see LICENSE for more details.
 """
 try:
@@ -21,11 +21,11 @@ from django.views.decorators.cache import never_cache
 from django.views.decorators.csrf import csrf_protect
 from django.views.generic import View
 from django.utils.decorators import method_decorator
+from django.utils.http import is_safe_url
 from django.utils.module_loading import import_string
 
-from sudo.settings import (REDIRECT_FIELD_NAME, REDIRECT_URL,
-                           REDIRECT_TO_FIELD_NAME, URL)
-from sudo.utils import grant_sudo_privileges, is_safe_url
+from sudo.settings import REDIRECT_FIELD_NAME, REDIRECT_URL, REDIRECT_TO_FIELD_NAME, URL
+from sudo.utils import grant_sudo_privileges
 from sudo.forms import SudoForm
 
 
@@ -35,18 +35,18 @@ class SudoView(View):
     prompt the user for their password again, and if successful, redirect
     them back to ``next``.
     """
+
     form_class = SudoForm
-    template_name = 'sudo/sudo.html'
+    template_name = "sudo/sudo.html"
     extra_context = None
 
     def handle_sudo(self, request, redirect_to, context):
-        return request.method == 'POST' and context['form'].is_valid()
+        return request.method == "POST" and context["form"].is_valid()
 
     def grant_sudo_privileges(self, request, redirect_to):
         grant_sudo_privileges(request)
         # Restore the redirect destination from the GET request
-        redirect_to = request.session.pop(REDIRECT_TO_FIELD_NAME,
-                                          redirect_to)
+        redirect_to = request.session.pop(REDIRECT_TO_FIELD_NAME, redirect_to)
         # Double check we're not redirecting to other sites
         if not is_safe_url(url=redirect_to, host=request.get_host()):
             redirect_to = resolve_url(REDIRECT_URL)
@@ -66,12 +66,12 @@ class SudoView(View):
         if request.is_sudo():
             return HttpResponseRedirect(redirect_to)
 
-        if request.method == 'GET':
+        if request.method == "GET":
             request.session[REDIRECT_TO_FIELD_NAME] = redirect_to
 
         context = {
-            'form': self.form_class(request.user, request.POST or None),
-            'request': request,
+            "form": self.form_class(request.user, request.POST or None),
+            "request": request,
             REDIRECT_FIELD_NAME: redirect_to,
         }
         if self.handle_sudo(request, redirect_to, context):
@@ -103,6 +103,6 @@ def redirect_to_sudo(next_url, sudo_url=None):
 
     querystring = QueryDict(sudo_url_parts[4], mutable=True)
     querystring[REDIRECT_FIELD_NAME] = next_url
-    sudo_url_parts[4] = querystring.urlencode(safe='/')
+    sudo_url_parts[4] = querystring.urlencode(safe="/")
 
     return HttpResponseRedirect(urlunparse(sudo_url_parts))
